/*
*  Rubrica
*  file: druid_cb.h
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#include "prefer.h"
#include "druid_cb.h"
#include "main.h"


void
on_druidpagefinish1_finish             (GnomeDruidPage  *gnomedruidpage,
                                        gpointer         arg1,
                                        gpointer         user_data)
{ 
  gchar *home;
  gchar *text;
  gchar *dicthome;

  gtk_widget_destroy(user_data);

  rubrica_preferences_set_first_run(FALSE);

  home = g_get_home_dir();
  rubrica_preferences_set_home(home);

  dicthome = g_strdup_printf("%s/.rubrica/dictionary", home);

  text = rubrica_preferences_get_default_folder();

  if (!g_file_exists(text))
    {
      gchar *message;
      
      message = g_strdup_printf(_("\nfolder: %s don't exist.Created\n"), text);

      mkdir(text, S_IRUSR | S_IWUSR | S_IXUSR); 		
      g_print(message);
//      rubrica_message(message);
      
      g_free(message);
    }

  rubrica_preferences_set_dictionary_home(dicthome);
  if (!g_file_exists(dicthome))
    {
      gchar *message;
      
      message = g_strdup_printf(_("dictionary folder: %s don't exist.Created\n"), 
				dicthome);

      mkdir(dicthome, S_IRUSR | S_IWUSR | S_IXUSR); 		
      g_print(message);
//      rubrica_message(message);
      
      g_free(message);
    }
  
  rubrica_begin();
}

void
on_druidpage_cancel             (GnomeDruidPage  *gnomedruidpage,
                                 gpointer         arg1,
                                 gpointer         user_data)
{
  gtk_widget_destroy(user_data);  

  rubrica_begin();
}


void
on_check_book_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  GtkWidget *fileentry = user_data;
  gboolean bool;

  bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));  

  gtk_widget_set_sensitive(fileentry, bool);
  rubrica_preferences_set_have_default_book(bool);
}

void
on_check_folder_toggled                  (GtkToggleButton *togglebutton,
					  gpointer         user_data)
{
  GtkWidget *fileentry = user_data;
  gboolean bool;

  bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  gtk_widget_set_sensitive(fileentry, bool);
  rubrica_preferences_set_have_default_folder(bool);  
}


void
on_entry_book_activate                 (GtkEditable     *editable,
                                        gpointer         user_data)
{
  on_entry_book_changed(editable, NULL);
}


void on_entry_book_changed                  (GtkEditable     *editable,
                                             gpointer         user_data)
{
  gchar *text;
  
  g_return_if_fail(editable != NULL);
  
  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  rubrica_preferences_set_book(text); 
  
  g_free(text);  
}



void
on_entry_folder_activate               (GtkEditable     *editable,
                                        gpointer         user_data)
{
  on_entry_folder_changed(editable, NULL);  
}


void
on_entry_folder_changed                (GtkEditable     *editable,
                                        gpointer         user_data)
{
  gchar *text;
  
  g_return_if_fail(editable != NULL);
  
  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  rubrica_preferences_set_folder(text); 
  
  g_free(text);  
}

