/*
*  Rubrica
*  file: modulo.c
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/*
  modulo rubrica, derivato da gnome-propertybox
*/

#include <gnome.h>
#include <time.h>
#include "rubrica.h"
#include "modulo.h"
#include "modulo_int.h"
#include "error.h"


enum {
  HELP,
  LAST_SIGNAL
};


typedef void (*ModuloRubricaSignal) (GtkObject *object, gint arg, gpointer data);

static void modulo_rubrica_class_init     (ModuloRubricaClass *klass);
static void modulo_rubrica_init           (ModuloRubrica *modulo);
static void modulo_rubrica_marshal_signal (GtkObject *object, GtkSignalFunc func, 
					   gpointer func_data, GtkArg *args);

static void modulo_rubrica_destroy        (GtkObject *object);
void  modulo_rubrica_info_init(ModuloRubrica *m);

static void modulo_rubrica_dialog_clicked_cb(GnomeDialog *dialog, gint bottone, 
					     gpointer data);
static void modulo_rubrica_aiuto  (ModuloRubrica *modulo);
static void modulo_rubrica_chiudi (ModuloRubrica *modulo);


/* classe genitore */
static GnomeDialogClass *parent_class = NULL;


/* funzione che gestisce i segnali della classe modulo */  
static gint modulo_rubrica_signals[LAST_SIGNAL] = { 0 };


/* conserva il tipo di telefono selezionato, ed attualmente attivo */
static gchar telefono_attivo[12];
static gboolean modificato = FALSE;

/* Widget modulo: make one, return more */
static GtkWidget *ModuloWidget; 

/* modulo widget counter */
static gint count = 0;

/* temporary time variables */
time_t created, changed;



/*    modulo_rubrica_get_type
      ritorna il GtkType del widget ModuloRubrica
*/
GtkType 
modulo_rubrica_get_type(void)
{
  static guint modulo_rubrica_type = 0;
  
  if (!modulo_rubrica_type)
    {
      static const GtkTypeInfo modulo_rubrica_info =
      {
	"ModuloRubrica",
	sizeof(ModuloRubrica),
	sizeof(ModuloRubricaClass),
	(GtkClassInitFunc)  modulo_rubrica_class_init,
	(GtkObjectInitFunc) modulo_rubrica_init,
	NULL, /* riservato per compatibilit */
	NULL, /* riservato per compatibilit */
      };

      modulo_rubrica_type = gtk_type_unique(gnome_dialog_get_type(), 
					    &modulo_rubrica_info);
    }

  return modulo_rubrica_type;
};


/*  inizializzazione della classe ModuloRubrica
*/
static void
modulo_rubrica_class_init(ModuloRubricaClass *klass)
{
  GtkObjectClass *object_class;
  GtkWidgetClass *widget_class;
  GtkWindowClass *window_class;

  object_class = (GtkObjectClass*) klass;
  widget_class = (GtkWidgetClass*) klass;
  window_class = (GtkWindowClass*) klass;

  object_class->destroy = modulo_rubrica_destroy;
 
  parent_class = gtk_type_class(gnome_dialog_get_type());

/*  segnali gestiti dalla classe
*/

 modulo_rubrica_signals[HELP] =
    gtk_signal_new ("help", 
		    GTK_RUN_LAST,
		    object_class->type,
		    GTK_SIGNAL_OFFSET(ModuloRubricaClass, modulo_rubrica_aiuto),
		    modulo_rubrica_marshal_signal,
		    GTK_TYPE_NONE, 1, GTK_TYPE_INT);

 gtk_object_class_add_signals (object_class, modulo_rubrica_signals, LAST_SIGNAL);

 klass->modulo_rubrica_aiuto = NULL;
}


static void
modulo_rubrica_marshal_signal (GtkObject *object, GtkSignalFunc func,
			       gpointer func_data, GtkArg *args)
{
  ModuloRubricaSignal rfunc;

  rfunc = (ModuloRubricaSignal) func;
  (*rfunc) (object, GTK_VALUE_INT(args[0]), func_data);
}


/*  inizializzazione della struttura dati ModuloRubrica
*/
static void
modulo_rubrica_init (ModuloRubrica *modulo)
{
  /* bottoni globali al widget */ 
  GList *button_list;

  /* frame */
  GtkWidget *frame_dati;
  GtkWidget *frame_rete;
  GtkWidget *frame_telefono;
  GtkWidget *frame_work;
  GtkWidget *frame_note;

  /* etichette notebook */
  GtkWidget *label_dati;
  GtkWidget *label_rete;
  GtkWidget *label_telefono;
  GtkWidget *label_work;
  GtkWidget *label_note;

  modulo->notebook = gtk_notebook_new();

  /* bottoni globali alla finestra di dialogo modulo */
  gnome_dialog_append_buttons(GNOME_DIALOG(modulo),
			      GNOME_STOCK_BUTTON_OK,				
			      GNOME_STOCK_BUTTON_HELP,
  			      GNOME_STOCK_BUTTON_CLOSE,
			      NULL);
  /*     bottone di default: -- ok
  */
  gnome_dialog_set_default (GNOME_DIALOG(modulo), 0);

  /*    lista dei bottoni
  */
  button_list = GNOME_DIALOG(modulo)->buttons;
  
  /*     salvo nella struttura dati ModuloRubrica i ptr ai bottoni
  */
  modulo->ok = GTK_WIDGET(button_list->data);

  /*    il prossimo bottone  ...
  */
  button_list = button_list->next;
  modulo->cancella = GTK_WIDGET(button_list->data);

  button_list = button_list->next;
  modulo->aiuto = GTK_WIDGET(button_list->data);
  
  /*    segnali gestiti dal modulo 
	- il segnale clicked  relativo all'intero modulo,
	   il modulo ad emettere il segnale clicked, che
	  viene gestito da dialog_clicked_cb, che dirige
	  l'esecuzione in modo appropriato
  */
  gtk_signal_connect ( GTK_OBJECT(modulo), "clicked",
		       GTK_SIGNAL_FUNC(modulo_rubrica_dialog_clicked_cb),
		       NULL);
  /* connettere ad una funzione che modifica il titolo della 
     finestra, per indicare che  avvenuto un cambiamento 
  */
  
  gtk_box_pack_start (GTK_BOX(GNOME_DIALOG(modulo)->vbox),
		      modulo->notebook,
		      TRUE, TRUE, 0);

  /* Hide dialog on close signal */
  gnome_dialog_close_hides(GNOME_DIALOG(modulo), TRUE);

  /* increase modulo counter */
  count++;

  /*    creo le pagine del notebook:
	-- se si render necessario aggiungere altre pagine
	   nel notobook, si dovr fare qui, utilizzando una funzione 
	   simile a quelle in basso, creare un frame che contiene
	   la pagina e inserire il tutto nel notebook.
  */
  frame_dati = modulo_rubrica_crea_pagina_dati(modulo);
  frame_rete = modulo_rubrica_crea_pagina_rete(modulo);
  frame_telefono = modulo_rubrica_crea_pagina_telefono(modulo);
  frame_work = modulo_rubrica_crea_pagina_work(modulo);
  frame_note = modulo_rubrica_crea_pagina_note(modulo);

  label_dati = gtk_label_new(_(" Data "));
  label_rete = gtk_label_new(_(" Net "));
  label_telefono = gtk_label_new(_(" Telephone "));
  label_work = gtk_label_new(_(" Work "));
  label_note = gtk_label_new(_(" Notes "));

  /*     inserisco le pagine nel notebook
  */
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_dati, label_dati);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_rete, label_rete);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_telefono, 
			   label_telefono);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_work, label_work);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_note, label_note);

  gtk_widget_show (modulo->notebook);
}


static void
modulo_rubrica_destroy(GtkObject *object)
{
  ModuloRubrica *modulo;
  
  g_return_if_fail (object != NULL);
  g_return_if_fail (IS_MODULO_RUBRICA(object));

  /*   DA FARE:
       verificare se occorre svuotare le clist
       prima di distruggere il modulo
  */
  modulo = MODULO_RUBRICA(object);

  GTK_OBJECT_CLASS(parent_class)->destroy (object);
}


GtkWidget *
modulo_rubrica_new(MODO_MODULO modo)
{
  GtkWidget *modulo;
  
  if (count == 0)
    {
    modulo = gtk_type_new(modulo_rubrica_get_type());

    modulo_rubrica_set_modulo(modulo);
    }
  else 
    {
    modulo = modulo_rubrica_get_modulo();

    modulo_rubrica_clean_modulo(MODULO_RUBRICA(modulo));
    }

  MODULO_RUBRICA(modulo)->modo = modo;    

  /* init some data scructures
   */
  modulo_rubrica_info_init(MODULO_RUBRICA(modulo));

  /*    set modulo notebook default page
  */
  gtk_notebook_set_page(GTK_NOTEBOOK(MODULO_RUBRICA(modulo)->notebook), 0);

  /* set default telephone
   */
  strcpy(telefono_attivo, "home");  

  return GTK_WIDGET(modulo);

}

/*   return saved modulo pointer 
*/
GtkWidget *modulo_rubrica_get_modulo(void)
{
  return (GtkWidget *) ModuloWidget;
}

/*  store modulo widget for future
*/

void modulo_rubrica_set_modulo(GtkWidget *wid)
{
  g_return_if_fail( wid != NULL);

  ModuloWidget = (GtkWidget*) wid;
}

void modulo_rubrica_clean_modulo(ModuloRubrica *modulo)
{
  g_return_if_fail(modulo != NULL);
  
  /*    Card
   */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "card_entry")), "");
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo), 
						  "card_deleting_button")), FALSE);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo), 
						  "card_modifying_button")), FALSE);
  
  /* Personal data */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "first_name_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "middle_name_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "last_name_entry")), "");

  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "profession_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "name_prefix_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "title_entry")), "");
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo), 
						  "birthday_check")), FALSE);
  gnome_date_edit_set_time(GNOME_DATE_EDIT(gtk_object_get_data
					   (GTK_OBJECT(modulo), "birthday")),
			                    time(NULL));

  /* Address */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "street_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "street_num_entry")), "");
  gtk_entry_set_text(GTK_ENTRY( gtk_object_get_data(GTK_OBJECT(modulo), 
						    "zip_code_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "city_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "province_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "state_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "country_entry")), "");
  
  /* Net */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "web_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "email_entry")), ""); 
  gtk_clist_clear(GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo), "web_clist")));    
  gtk_clist_clear(GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo), "email_clist")));
  gtk_clist_clear(GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo), 
						"telephone_clist")));

  /* Company */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_street_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_street_number_entry")),"");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_zip_code_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_city_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_province_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_country_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_web_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_email_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_operator_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_fax_entry")), "");
  gtk_entry_set_text(GTK_ENTRY( gtk_object_get_data(GTK_OBJECT(modulo), 
						    "company_green_entry")), "");
  gtk_entry_set_text(GTK_ENTRY((gtk_object_get_data(GTK_OBJECT(modulo), 
						    "company_customer_entry"))), "");
  gtk_editable_delete_text(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo), "company_note_text")), 
			   0, -1);  

  /* Work */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "assigment_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "org_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "department_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "sub_dep_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "secretary_entry")), "");
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "phone_entry")), "");

  /* Notes */  
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo), 
						  "married_check")), FALSE);	       
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo), 
						  "children_check")), FALSE);
  
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "spouse_entry")), "");
  gnome_date_edit_set_time(GNOME_DATE_EDIT(gtk_object_get_data
					   (GTK_OBJECT(modulo), "spouse_birthday")),
			   time(NULL));
  gnome_date_edit_set_time(GNOME_DATE_EDIT(gtk_object_get_data
					   (GTK_OBJECT(modulo), "anniversary")),
			   time(NULL));
  gtk_editable_delete_text(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo), "children_text")), 0, -1);
  gtk_editable_delete_text(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo), "notes_text")), 0, -1);
  gtk_editable_delete_text(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo), "hobbies_text")), 0, -1);
  gtk_editable_delete_text(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo), "pub_key_text")), 0, -1);
}

/*   funzione di callback che gestisce il 
     segnale "clicked" emesso dal modulo
*/  
static void
modulo_rubrica_dialog_clicked_cb(GnomeDialog * dialog, gint button, gpointer data)
{
  ModuloRubrica *mod;

  g_return_if_fail(dialog != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(dialog));
  
  mod = MODULO_RUBRICA (dialog);

  switch(button) 
    {
    case 0:   /* cliccato ok, aggiunta nuova scheda, rubrica modificata */          
      if (mod->modo == NUOVO_MODULO) 
	{
	  rubrica_view_inc_indirizzi();
	  modulo_rubrica_estrai_inserisci_e_chiudi(mod);
	}
      if (mod->modo == MODIFICA_MODULO) 
	{
	  modulo_rubrica_estrai_sostituisci_e_chiudi(mod);       
	}
      rubrica_set_modified(TRUE);
      break;

    case 1:   /* cliccato aiuto, nessuna modifica */
      rubrica_set_modified(FALSE);
      modulo_rubrica_aiuto (MODULO_RUBRICA (dialog));
      break;

    case 2:   /* cliccato chiudi, nessuna modifica */
      rubrica_set_modified(FALSE);
      modulo_rubrica_chiudi (MODULO_RUBRICA (dialog));
      break;
    default:  /* non si deve arrivare a questo punto    */
              /* se si  qui, si  verificato un errore */
      g_assert_not_reached();
    }
}


void 
modulo_rubrica_info_init(ModuloRubrica *m)
{
  g_return_if_fail(m != NULL);

  modificato = FALSE;
  
  m->webinfo.riga = 0;
  m->webinfo.colonna = 0;
  m->webinfo.selezionato = FALSE;

  m->mailinfo.riga = 0;
  m->mailinfo.colonna = 0;
  m->mailinfo.selezionato = FALSE;

  m->telinfo.riga = 0;
  m->telinfo.colonna = 0;
  m->telinfo.selezionato = FALSE;
}


void 
modulo_rubrica_estrai_inserisci_e_chiudi(ModuloRubrica *m)
{
  RubricaItem *r;

  g_return_if_fail(m != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(m));

  /* estrazione dei dati contenuti nel modulo */
  r = modulo_rubrica_estrai_dati(m);

  /* Imposta la data di creazione e ultima modifica */
  r->created = r->last_change = time(NULL); 
  
  /* inserimento dei dati nella rubrica */
  rubrica_inserisci_elemento(r); 

  /* setto il flag di lista vuota a falso */
  rubrica_set_empty(FALSE);

  /* visualizzazione della scheda nell'apposita clist */
  rubrica_inserisci_scheda(r);

  /* chiudo il modulo */
  modulo_rubrica_chiudi(m);
}

void 
modulo_rubrica_estrai_sostituisci_e_chiudi(ModuloRubrica *m)
{
  RubricaItem *r;

  g_return_if_fail(m != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(m));

  /* estrazione dei dati contenuti nel modulo */
  r = modulo_rubrica_estrai_dati(m);

  /* Imposta la data di ultima modifica */
  r->created = created;
  r->last_change = time(NULL);

  /* inserimento dei dati nella rubrica */
  rubrica_modifica_elemento(r);
  
  /* setto il flag di lista vuota a falso */
  rubrica_set_empty(FALSE);
  
  /* visualizzazione della scheda nell'apposita clist */
  rubrica_modifica_scheda(r);

  /* visualizzo i nuovi dati nella lista dati */
  rubrica_mostra_scheda(r); 

  /* chiudo il modulo */
  modulo_rubrica_chiudi(m);
}


/*   DA TERMINARE 
*/
static void
modulo_rubrica_aiuto (ModuloRubrica *modulo)
{
  gint page;
  
  page = gtk_notebook_get_current_page (GTK_NOTEBOOK (modulo->notebook));
  gtk_signal_emit (GTK_OBJECT (modulo), modulo_rubrica_signals[HELP],page);

  /* to do */
}


static void
modulo_rubrica_chiudi (ModuloRubrica *modulo)
{
  gnome_dialog_close(GNOME_DIALOG(modulo));
}


gboolean 
modulo_rubrica_modulo_is_modificato()
{
  return (gboolean) modificato;
}


/*   funzioni per manipolare i dati contenuti nel widget

     estrae i dati contenuti nella finestra di dialogo e 
     li salva nella rubrica
*/
RubricaItem 
*modulo_rubrica_estrai_dati(ModuloRubrica *modulo)
{
  RubricaItem *r;
  TelNum *tt;
  GtkCList *clist;

  gint riga;
  gint rows;
  gchar *web;
  gchar *mail;
  gchar *numero;
  gchar *tipo;

  GList *weblist;  
  GList *maillist; 
  GList *tellist;

  g_return_val_if_fail(modulo != NULL, NULL);
  g_return_val_if_fail(IS_MODULO_RUBRICA(modulo), NULL);

  /* alloco la memoria necessaria per contenere i dati */
  r = g_malloc (sizeof(RubricaItem));

  /* Card data */
  r->scheda = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "card_entry"))));
  r->editabile = 
    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						   (GTK_OBJECT(modulo), 
						    "card_modifying_button")));  
  r->cancellabile = 
    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						   (GTK_OBJECT(modulo), 
						    "card_deleting_button")));  

  /* Personal data
     estrazione dei dati relativi al nominativo, domicilio, ... 
  */
  r->personal.first_name =
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "first_name_entry"))));
  r->personal.middle_name = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "middle_name_entry"))));
  r->personal.last_name = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "last_name_entry"))));
  
  r->personal.profession = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "profession_entry"))));
  r->personal.name_prefix =
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "name_prefix_entry"))));
  r->personal.title = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "title_entry"))));
  r->personal.birthday_setted =  
    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						   (GTK_OBJECT(modulo), 
						    "birthday_check")));  
  r->personal.birthday = 
    gnome_date_edit_get_date(GNOME_DATE_EDIT(gtk_object_get_data
					     (GTK_OBJECT(modulo),
					      "birthday")));
  /*	Address data
  */
  r->address.street =
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "street_entry"))));
  r->address.number =
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "street_num_entry"))));
  r->address.zip_code = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "zip_code_entry"))));
  r->address.city =
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "city_entry"))));    
  r->address.province = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "province_entry"))));
  r->address.state = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "state_entry"))));
  r->address.country =
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo), 
					   "country_entry"))));    

  /*    Company data
  */
  r->company.name = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_entry"))));
  r->company.street = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_street_entry" ))));
  r->company.number = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_street_number_entry"))));
  r->company.zip_code = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_zip_code_entry"))));
  r->company.city  = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_city_entry"))));
  r->company.province = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_province_entry"))));
  r->company.country = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_country_entry"))));
  r->company.web = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_web_entry" ))));
  r->company.email = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_email_entry"))));
  r->company.operator = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_operator_entry"))));
  r->company.fax = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_fax_entry"))));
  r->company.green = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_green_entry"))));
  r->company.customer_care = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "company_customer_entry"))));
  r->company.notes = 
    gtk_editable_get_chars(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo),
					 "company_note_text")), 0,-1);  
  
  /*     Work data
  */
  r->work.assigment =  
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "assigment_entry"))));
  r->work.organization = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "org_entry"))));
  r->work.department = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "department_entry"))));
  r->work.sub_dep = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "sub_dep_entry"))));
  r->work.secretary_name = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "secretary_entry"))));
  r->work.secretary_phone = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "phone_entry"))));
  
  /*    Personal notes
  */
  r->notes.married = 
    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						   (GTK_OBJECT(modulo), 
						    "married_check"))); 
  r->notes.children = 
    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						   (GTK_OBJECT(modulo), 
						    "children_check")));   
  r->notes.spouse_name = 
    g_strdup(gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data
					  (GTK_OBJECT(modulo),
					   "spouse_entry" ))));
  r->notes.birthday = 
    gnome_date_edit_get_date(GNOME_DATE_EDIT(gtk_object_get_data
					     (GTK_OBJECT(modulo),
					      "spouse_birthday")));  
  r->notes.anniversary = 
    gnome_date_edit_get_date(GNOME_DATE_EDIT(gtk_object_get_data
					     (GTK_OBJECT(modulo),
					      "anniversary")));  
  r->notes.child = 
    gtk_editable_get_chars(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo),
					 "children_text")), 0,-1);       
  r->notes.hobby = 
    gtk_editable_get_chars(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo),
					 "hobbies_text")), 0,-1);        
  r->notes.notes = 
    gtk_editable_get_chars(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo),
					 "notes_text")), 0,-1);  
  r->notes.public_key =
    gtk_editable_get_chars(GTK_EDITABLE(gtk_object_get_data
					(GTK_OBJECT(modulo),
					 "pub_key_text")), 0,-1);  

  /* estrazione dei dati dalle liste, web, mail e telefonica */
  
  /* NOTA:
     faccio iniziare riga da zero, mentre il numero di elementi inseriti
     nelle clist inizia da uno. Allora devo fermare il conto a rows-1 se
     inizio con riga da zero. Mi fermo a rows, se far iniziare riga da 1
  */
  
  /*    web
   */
  /*
  r->net.web_list = 
    r->net.mail_list = 
    r->telephone.tel_list = NULL;
  r->net.nweb = 
    r->net.nmail = 
    r->telephone.ntel = 0; 
  */  
  clist = GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo),"web_clist"));
  rows = clist->rows;
  riga = 0;
  weblist = NULL;
  while ( riga < rows )
    {
      gchar *buffer;
      
      gtk_clist_get_text(GTK_CLIST(clist), riga, 1, &web);
      
      buffer = g_strdup(web);
      weblist = g_list_append(weblist, buffer);
      riga++;
    }
  r->net.web_list = weblist;  // la lista delle pagine web
  r->net.nweb = rows;         // il numero degli url web
  
  /*    mail
   */
  clist = GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo),"email_clist"));
  rows = clist->rows;
  riga = 0;
  maillist = NULL;
  while (riga < rows )
    {
      gchar *buffer;
      
      gtk_clist_get_text(GTK_CLIST(clist), riga, 1, &mail);
      
      buffer = g_strdup(mail);
      maillist = g_list_append(maillist, buffer);
      riga++;
    }
  r->net.mail_list = maillist;
  r->net.nmail = rows;
  
  /*    Telefono
   */
  clist = GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo),"telephone_clist"));
  rows = clist->rows;
  riga = 0;
  tellist = NULL;
  while ( riga < rows )
    {
      tt = g_malloc(sizeof(TelNum));
      
      gtk_clist_get_text(GTK_CLIST(clist), riga, 1, &numero);
      gtk_clist_get_text(GTK_CLIST(clist), riga, 2, &tipo);
      
      tt->numero_telefono = g_strdup(numero);
      tt->tipo = g_strdup(tipo);
      
      tellist = g_list_append(tellist, tt);
      riga++;
    }
  r->telephone.tel_list = tellist;
  r->telephone.ntel = rows;
  
  return (RubricaItem *) r;
}

/*
    visualizza i dati contenuti nell'elemento di 
    rubrica, nella finestra di dialogo
*/
RUBRICA_ERROR 
modulo_rubrica_inserisci_dati(ModuloRubrica *modulo, RubricaItem *r)
{
  GtkWidget *spouse_entry;
  GtkWidget *spouse_birthday;
  GtkWidget *anniversary;
  GtkWidget *child; 

  GList *weblist; 
  GList *maillist;
  GList *tellist;
  
  gint righe;
  gint company_note = 0, note = 0, hobby = 0, public_key = 0, child_pos = 0;

  g_return_val_if_fail(modulo != NULL, RUBRICA_ERROR_MODULE_IS_NULL);
  g_return_val_if_fail(IS_MODULO_RUBRICA(modulo), RUBRICA_ERROR_BAD_MODULE);
  g_return_val_if_fail(r != NULL, RUBRICA_ERROR_NO_ITEM_MODULE);

  created = r->created;
  changed = r->last_change;

  /*     Card data 
  */  
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo),
						  "card_modifying_button")),
			       r->editabile);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo),
						  "card_deleting_button")),
			       r->cancellabile);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "card_entry")), r->scheda);

  /*    Personal data
  */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "first_name_entry")),
		     r->personal.first_name);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "middle_name_entry")), 
		     r->personal.middle_name);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "last_name_entry")), 
		     r->personal.last_name);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "profession_entry")), 
		     r->personal.profession);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "name_prefix_entry")), 
		     r->personal.name_prefix);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "title_entry")), 
		     r->personal.title);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data
						 (GTK_OBJECT(modulo),
						  "birthday_check")),
			       r->personal.birthday_setted);

  gnome_date_edit_set_time(GNOME_DATE_EDIT(gtk_object_get_data
					   (GTK_OBJECT(modulo), "birthday")),
			   r->personal.birthday);
  
  /* address */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "street_entry")), 
		     r->address.street);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "street_num_entry")), 
		     r->address.number);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "zip_code_entry")), 
		     r->address.zip_code);

  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "city_entry")), 
		     r->address.city);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "province_entry")), 
		     r->address.province);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "state_entry")), 
		     r->address.state);

  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "country_entry")), 
		     r->address.country);

  /* inserimento dei dati dalle liste, web, mail e telefonica */
  
  /*    web
   */
  if (r->net.web_list) {
    weblist = r->net.web_list;
    righe = r->net.nweb;
  }   
  else {
    weblist = NULL;
    righe = 0;
  }
  while (righe)
    {    
      gchar *buffer[3] = {NULL, NULL, NULL};
      
      buffer[1] = g_strdup(weblist->data);
      gtk_clist_append(GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo), 
						     "web_clist")), buffer);
      weblist = g_list_next(weblist);
      righe--;
    }
  
  /*    mail
   */
  if (r->net.mail_list) {
    righe = r->net.nmail;
    maillist = r->net.mail_list;
  }
  else {
    righe = 0;
    maillist = NULL;
  }
  while (righe)
    {
      gchar *buffer[3] = {NULL, NULL, NULL};

      buffer[1] = g_strdup(maillist->data);
      gtk_clist_append(GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo), 
						     "email_clist")), buffer);
      maillist = g_list_next(maillist);
      righe--;
    }

  /*    Telefono
   */
  if (r->telephone.tel_list) {
    righe = r->telephone.ntel;
    tellist = r->telephone.tel_list;
  }
  else {
    righe = 0;
    tellist = NULL;
  }
  while (righe)
    {       
      /* buffer[0] riservato per l'eventuale pixmap */
      gchar *buffer[4] = {NULL, NULL, NULL, NULL};
      TelNum *tt = (TelNum*) tellist->data;

      buffer[1] = g_strdup(tt->numero_telefono);
      buffer[2] = g_strdup(tt->tipo);
      gtk_clist_append(GTK_CLIST(gtk_object_get_data(GTK_OBJECT(modulo), 
						     "telephone_clist")), buffer);
      tellist = g_list_next(tellist);     
      righe--;
    }

  /* company */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_entry")), 
		     r->company.name);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_street_entry")), 
		     r->company.street );
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_street_number_entry")), 
		     r->company.number);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_zip_code_entry")), 
		     r->company.zip_code);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_city_entry")), 
		     r->company.city);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_province_entry")), 
		     r->company.province);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_country_entry")), 
		     r->company.country);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_web_entry")), 
		     r->company.web);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_email_entry")), 
		     r->company.email);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_operator_entry")), 
		     r->company.operator);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_fax_entry")), 
		     r->company.fax);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_green_entry")), 
		     r->company.green);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "company_customer_entry")), 
		     r->company.customer_care);
  gtk_editable_insert_text(GTK_EDITABLE(gtk_object_get_data(GTK_OBJECT(modulo), 
							    "company_note_text")),
			   r->company.notes, strlen(r->company.notes), 
			   &company_note);
  
  /* work */
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "assigment_entry")), 
		     r->work.assigment);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "org_entry")), 
		     r->work.organization);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "department_entry")), 
		     r->work.department);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "sub_dep_entry")), 
		     r->work.sub_dep);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "secretary_entry")), 
		     r->work.secretary_name);
  gtk_entry_set_text(GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(modulo), 
						   "phone_entry")), 
		     r->work.secretary_phone);
  
  /* note */ 
  spouse_entry = gtk_object_get_data(GTK_OBJECT(modulo), "spouse_entry");
  spouse_birthday = gtk_object_get_data(GTK_OBJECT(modulo), "spouse_birthday");
  anniversary = gtk_object_get_data(GTK_OBJECT(modulo), "anniversary");
  child = gtk_object_get_data(GTK_OBJECT(modulo), "children_text");

  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
			       (gtk_object_get_data(GTK_OBJECT(modulo),
						    "married_check")),
			       r->notes.married);     
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
			       (gtk_object_get_data(GTK_OBJECT(modulo),
						    "children_check")),
			       r->notes.children);

  gtk_entry_set_text(GTK_ENTRY(spouse_entry), r->notes.spouse_name);
  gnome_date_edit_set_time(GNOME_DATE_EDIT(spouse_birthday), r->notes.birthday);
  gnome_date_edit_set_time(GNOME_DATE_EDIT(anniversary), r->notes.anniversary);
  gtk_editable_insert_text(GTK_EDITABLE(child), r->notes.child, 
			   strlen(r->notes.child), &child_pos);
  
  gtk_widget_set_sensitive(spouse_entry, r->notes.married);
  gtk_widget_set_sensitive(spouse_birthday, r->notes.married);  
  gtk_widget_set_sensitive(anniversary, r->notes.married);
  gtk_widget_set_sensitive(child, r->notes.children);
  
  gtk_editable_insert_text(GTK_EDITABLE(gtk_object_get_data(GTK_OBJECT(modulo), 
							    "hobbies_text")),
			   r->notes.hobby, strlen(r->notes.hobby), 
			   &hobby);
  gtk_editable_insert_text(GTK_EDITABLE(gtk_object_get_data(GTK_OBJECT(modulo), 
							    "notes_text")),
			   r->notes.notes, strlen(r->notes.notes), 
			   &note);
  gtk_editable_insert_text(GTK_EDITABLE(gtk_object_get_data(GTK_OBJECT(modulo), 
							    "pub_key_text")),
			   r->notes.public_key, strlen(r->notes.public_key), 
			   &public_key);

  return RUBRICA_ERROR_NO_ERROR;
}

void modulo_rubrica_add_child(ModuloRubrica *mod, GtkWidget *child)
{
  g_return_if_fail(mod != NULL);
  g_return_if_fail(child != NULL);

  mod->childs = g_list_append(mod->childs, child);
}

RUBRICA_ERROR
modulo_rubrica_modifica_elemento(RubricaItem *r)
{
  GtkWidget *modulo;

  g_return_val_if_fail(r != NULL, RUBRICA_ERROR_NO_ITEM_MODULE);

  modulo = modulo_rubrica_new(MODIFICA_MODULO);

  modulo_rubrica_inserisci_dati(MODULO_RUBRICA(modulo), r);  
  gtk_widget_show(modulo);

  return RUBRICA_ERROR_NO_ERROR;
}


gchar 
*modulo_rubrica_get_telefono_attivo(void)
{
  return (gchar *) g_strdup(telefono_attivo);
}


void 
modulo_rubrica_set_telefono_attivo(gchar *str)
{
  strcpy(telefono_attivo, str);
}


TELEPHONE_TYPE
modulo_rubrica_tipo_telefono_int(gchar *tipo)
{
  g_return_val_if_fail(tipo != NULL, TELEPHONE_UNKNOWN);

  if ((strcasecmp(tipo, "home") == 0) ||      
      (strcasecmp(tipo, "Casa") == 0))
    return TELEPHONE_HOME;

  if ((strcasecmp(tipo, "work") == 0) ||
      (strcasecmp(tipo, "Ufficio") == 0))
    return TELEPHONE_WORK;

  if ((strcasecmp(tipo, "fax") == 0) ||
      (strcasecmp(tipo, "Fax") == 0))
    return TELEPHONE_FAX;
  
  if ((strcasecmp(tipo, "cellphone") == 0) ||
      (strcasecmp(tipo, "Cellulare") == 0))
    return TELEPHONE_CELLPHONE;

  if ((strcasecmp(tipo, "other") == 0) ||
      (strcasecmp(tipo, "Altro") == 0))
    return TELEPHONE_OTHER;

  return TELEPHONE_UNKNOWN;
}
























