/*
*  program name: Rubrica <http://digilander.iol.it/nfragale/download.html>
*  file: prefer.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf-client.h>
#include <gconf/gconf-schema.h>
#include <gnome-xml/tree.h>
#include <time.h>

#include "main.h"
#include "error.h"
#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer.h"
#include "rubrica.h"

#undef DEBUG

gchar *buffer_error[25];
gint error = 0;
gboolean key_error = FALSE;
gboolean user_dictionary_loaded;

void rubrica_preferences_display_messages(gchar *str)
{
  g_print("\n\nPlease send this message to nicolafragale@libero.it\nLa routine %s non riesce a leggere le preferenze, n quelle impostate dall'utente, n dal file schema", 
	  str);
}


void rubrica_preferences_reset_errors(void)
{
  gint i;

  error = 0;
  key_error = FALSE;
  for (i=0; i<25;i++)
    buffer_error[i] = NULL;
}

gchar **rubrica_preferences_get_buffer_error(void)
{
  return (gchar **) buffer_error;
}

gboolean rubrica_preferences_there_are_errors(void)
{
  return key_error;
}




GConfClient *rubrica_preferences_get_client(void)
{
  GtkWidget *prefbox;
  GConfClient *client;

  prefbox = rubrica_preferences_get_preferencesbox();
  client = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  return (GConfClient *) client;
}


GConfChangeSet *rubrica_preferences_get_change_set(GtkWidget *prefbox)
{
  return gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
}


void rubrica_preferences_update_sensitivity(GtkWidget *prefbox)
{
  GtkWidget* apply;
  GtkWidget* revert;
  GtkWidget* ok;

  GConfChangeSet* cs;
  GConfChangeSet* revert_cs;
  
  ok     = gtk_object_get_data(GTK_OBJECT(prefbox), "ok");
  apply  = gtk_object_get_data(GTK_OBJECT(prefbox), "apply");
  revert = gtk_object_get_data(GTK_OBJECT(prefbox), "revert");
  
  cs = rubrica_preferences_get_change_set(prefbox);
  revert_cs = gtk_object_get_data(GTK_OBJECT(prefbox), "revert_cs");

  if (gconf_change_set_size(cs) > 0)
    {
      gtk_widget_set_sensitive(ok, TRUE);
      gtk_widget_set_sensitive(apply, TRUE);
    }
  else
    {
      gtk_widget_set_sensitive(ok, TRUE);
      gtk_widget_set_sensitive(apply, FALSE);
    }
  
  if (revert_cs != NULL)
    gtk_widget_set_sensitive(revert, TRUE);
  else
    gtk_widget_set_sensitive(revert, FALSE);  
}


void rubrica_preferences_apply(GtkWidget *prefbox)
{

  GConfChangeSet *cs;
  GConfChangeSet *revert_cs;
  GConfClient *client;
  
  cs        = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  client    = gtk_object_get_data(GTK_OBJECT(prefbox), "client");
  revert_cs = gtk_object_get_data(GTK_OBJECT(prefbox), "revert_cs");
  
  /* Create the revert changeset on the first apply; this means
     the revert button should now be sensitive */
  if (revert_cs == NULL)
    {
      revert_cs = gconf_client_change_set_from_current(client, NULL,
						       RUBRICA_KEY_LAST_RUN,      
						       RUBRICA_KEY_SHOW,           
						       RUBRICA_KEY_HAVE_BOOK, 
						       RUBRICA_KEY_BOOK,
						       RUBRICA_KEY_HAVE_FOLDER,
						       RUBRICA_KEY_FOLDER, 
						       RUBRICA_KEY_BACKUP,  
						       RUBRICA_KEY_COMPRESS,
						       RUBRICA_KEY_RATE,    
						       RUBRICA_KEY_INCREASE,
						       RUBRICA_KEY_ALPHA_ORDER,
						       RUBRICA_KEY_DATE_ORDER,  
						       RUBRICA_KEY_SENSITIVE,
						       RUBRICA_KEY_COMPLETE,
						       RUBRICA_KEY_INCOMPLETE,    
						       RUBRICA_KEY_EXIT,    
						       RUBRICA_KEY_TIPS,     
						       RUBRICA_KEY_DEFAULT,  
						       RUBRICA_KEY_EXTERNAL,
						       RUBRICA_KEY_ITALIAN,  
						       RUBRICA_KEY_ENGLISH,
						       RUBRICA_KEY_USER_DICTIONARY,
						       NULL);
      
      gtk_object_set_data(GTK_OBJECT(prefbox), "revert_cs", revert_cs);
    }      

  gconf_client_commit_change_set(client, cs, TRUE, NULL);

  rubrica_preferences_update_sensitivity(prefbox);
} 


void 
rubrica_preferences_configure_radio(GtkWidget *radio1, 
				    GtkWidget *radio2,
				    GConfClient *client, 
				    gchar *key1,
				    gchar *key2)
{
  GConfValue *val_key;
  gboolean bool;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_radio");
  g_print("\nradio1: %p\nradio2: %p\nclient: %p\nkey1: %s\nkey2: %s", 
	  radio1, radio2, client, key1, key2);
#endif

  /*     get the value of key1 stored in gconf database
  */
  val_key = gconf_client_get(client, key1, NULL);

  /*    if rubrica was never run before, the value for key1 is NULL, so
	i will read default value stored in schema.
	if value isn't NULL and his type is BOOL then i read this value
  */
  if (val_key == NULL || val_key->type != GCONF_VALUE_BOOL)    
    val_key = gconf_client_get_default_from_schema(client, key1, NULL);      
  
  if (!val_key)
    {
      error_preferences_key(key1);
      
      key_error = TRUE;
      buffer_error[error] = g_strdup(key1);
      error++; 
      
      if (strcmp(key1, RUBRICA_KEY_ALPHA_ORDER) == 0)
	bool = rubrica_preferences_get_alphabetic_order();
      else if (strcmp(key1, RUBRICA_KEY_COMPLETE) == 0)
	bool = rubrica_preferences_get_complete_search();
      else if (strcmp(key1, RUBRICA_KEY_ITALIAN) == 0)
	bool = rubrica_preferences_get_use_italian_dictionary();
      
      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio1), bool);     
    }
  else
    {
      bool = gconf_client_get_bool(client, key1, NULL); 
      
      if (bool)
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio1), TRUE);
      else
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio2), TRUE); 
    }
}


void 
rubrica_preferences_configure_radio_dictionary(GtkWidget *radio1,  /* external dic */
					       GtkWidget *radio2,  /* default  dic */
					       GConfClient *client, 
					       gchar *key1,        /* external key */
					       gchar *key2)        /* default  key */
{
  GConfValue *val_key;
  
  GtkWidget *prefbox;
  GtkWidget *radio_italian;
  GtkWidget *radio_english;
  GtkWidget *entry;
  GtkWidget *notebook;
  GtkWidget *label_default;
  GtkWidget *label_language;
  GtkWidget *label_io;
  GtkWidget *label_dict;
  GtkWidget *load;
  GtkWidget *save;
  
  gboolean bool;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_radio_dictionary");
  g_print("\nradio1: %p\nradio2: %p\nclient: %p\nkey1: %s\nkey2: %s", 
	  radio1, radio2, client, key1, key2);
#endif

  /*    radio1 is the button for external dictionary, while 
	radio2 is the button for default dictionary
  */    
  prefbox = rubrica_preferences_get_preferencesbox();

  radio_italian  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ITALIAN);
  radio_english  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ENGLISH);
  label_default  = gtk_object_get_data(GTK_OBJECT(prefbox), "label_default_dict");
  entry        = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_USER_DICTIONARY);
  label_language = gtk_object_get_data(GTK_OBJECT(prefbox), "label_language");
  notebook       = gtk_object_get_data(GTK_OBJECT(prefbox), "notebook_dict");
  label_io       = gtk_object_get_data(GTK_OBJECT(prefbox), "label_io");
  label_dict     = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
  load           = gtk_object_get_data(GTK_OBJECT(prefbox), "load");
  save           = gtk_object_get_data(GTK_OBJECT(prefbox), "save");

  /*     get the value of key1 (external dictionary) stored in gconf database
  */
  val_key = gconf_client_get(client, key1, NULL);

  if (val_key == NULL || val_key->type != GCONF_VALUE_BOOL)    
    val_key = gconf_client_get_default_from_schema(client, key1, NULL);      

  if (!val_key)
    {
      error_preferences_key(key1);
      
      key_error = TRUE;
      buffer_error[error] = g_strdup(key1);
      error++; 

      bool = rubrica_preferences_get_use_user_dictionary();
    }
  else
    bool = gconf_client_get_bool(client, key1, NULL); 
    
  if (bool)    /* use external dictionary (user dictionary) */
    {
      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio1), TRUE);
      gtk_widget_set_sensitive(radio_italian, FALSE);
      gtk_widget_set_sensitive(radio_english, FALSE);
    }      
  else        /* use one of default dictionary */
    {
      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio2), TRUE);  
      gtk_widget_set_sensitive(radio_italian, TRUE);
      gtk_widget_set_sensitive(radio_english, TRUE);
    }
  
  gtk_widget_set_sensitive(label_default, !bool);

  gtk_widget_set_sensitive(entry, bool);
  gtk_widget_set_sensitive(label_language, bool);
  gtk_widget_set_sensitive(notebook, bool);
  gtk_widget_set_sensitive(label_io, bool);
  gtk_widget_set_sensitive(label_dict, bool);
  gtk_widget_set_sensitive(load, bool); 
  gtk_widget_set_sensitive(save, bool);      
}


void 
rubrica_preferences_configure_check(GtkWidget *check, GConfClient *client, gchar *key)
{
  GConfValue *key_value;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_check");
  g_print("\ncheck: %p\nclient: %p\nkey: %s", check, client, key);
#endif

  /*     get the value of key stored in gconf database
  */
  key_value = gconf_client_get(client, key, NULL);

  /*    if rubrica was never run before, the value for key is NULL, so
	i will read default value stored in schema.
	if value isn't NULL and his type is BOOL then i read this value
  */
  if (key_value == NULL || key_value->type != GCONF_VALUE_BOOL)
    key_value = gconf_client_get_default_from_schema(client, key, NULL);      
  
  if (!key_value)
    {
      gboolean bool;

      error_preferences_key(key);

      key_error = TRUE;
      buffer_error[error] = g_strdup(key);
      error++; 
      
      if (strcmp(key, RUBRICA_KEY_SHOW) == 0)
	bool = rubrica_preferences_get_show_path();
      
      else if (strcmp(key, RUBRICA_KEY_BACKUP) == 0)
	bool = rubrica_preferences_get_do_backup();
      
      else if (strcmp(key, RUBRICA_KEY_INCREASE) == 0)
	bool = rubrica_preferences_get_increasing_order();
      
      else if (strcmp(key, RUBRICA_KEY_EXIT) == 0)
	bool = rubrica_preferences_get_exit();
      
      else if (strcmp(key, RUBRICA_KEY_TIPS) == 0)
	bool = rubrica_preferences_get_tips();    

      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), bool);      
    }
  else
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
				  gconf_value_get_bool(key_value));
}


void 
rubrica_preferences_configure_checked_entry(GtkWidget *check, 
					    GtkWidget *gnome_entry,
					    GtkWidget *entry, 
					    GConfClient *client,
					    gchar *check_key,  
					    gchar *gentry_key)
{
  GConfValue *checkval = NULL;
  GConfValue *gentryval = NULL;  
  gboolean bool;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_checked_entry");
  g_print("\ncheck: %p\ngnome entry: %p\nentry: %p\nclient: %p\ncheck_key: %s\ngentry_key: %s", check, gnome_entry, entry, client, check_key, gentry_key);
#endif

  /* get the value stored in gconf database for the key "check_key"
  */
  checkval = gconf_client_get(client, check_key, NULL);

  /* if the database hasn't data for the key, then get the default value 
     from the schema
  */  
  if (checkval == NULL || checkval->type != GCONF_VALUE_BOOL)
    checkval = gconf_client_get_default_from_schema(client, check_key, NULL); 
    
  if (!checkval)
    {
      error_preferences_key(check_key);

      key_error = TRUE;
      buffer_error[error] = g_strdup(check_key);
      error++; 

      if (strcmp(check_key, RUBRICA_KEY_HAVE_BOOK) == 0)
	bool = rubrica_preferences_get_have_default_addressbook();
      
      else if (strcmp(check_key, RUBRICA_KEY_HAVE_FOLDER) == 0)
	bool = rubrica_preferences_get_have_default_folder();
    }
  else
    /* now I have a key value, and i can extract the boolean value  */
    bool = gconf_value_get_bool(checkval); 
  
  if (bool)
    {
      gchar *buffer = NULL;

      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), TRUE);
      gtk_widget_set_sensitive (gnome_entry, TRUE);
      
      /* again get the value stored in gconf database for the key "gentry_key"
       */
      gentryval = gconf_client_get(client, gentry_key, NULL); 
      
      if (gentryval == NULL || gentryval->type != GCONF_VALUE_STRING)  	
	gentryval = gconf_client_get_default_from_schema(client, gentry_key, NULL); 
      
      if (!gentryval)
	{
	  error_preferences_key(gentry_key);
	  
	  key_error = TRUE;
	  buffer_error[error] = g_strdup(gentry_key);
	  error++; 	  
	  
	  if (strcmp(gentry_key, RUBRICA_KEY_BOOK) == 0)
	    buffer = rubrica_preferences_get_book();
	  
	  else if (strcmp(gentry_key, RUBRICA_KEY_FOLDER) == 0)
	    buffer = rubrica_preferences_get_default_folder();	  
	}
      else
	/* get value stored in the key */
	buffer = gconf_value_get_string(gentryval);   

      if (buffer)
	{
	  gtk_entry_set_text (GTK_ENTRY (entry), buffer);

	  g_free(buffer);     
	}
      else
	gtk_entry_set_text (GTK_ENTRY (entry), "");      
    }
  else
    {
      gtk_entry_set_text (GTK_ENTRY (entry), "");
      gtk_widget_set_sensitive(gnome_entry, FALSE);
    }  
}

void rubrica_preferences_configure_spin(GtkWidget *check, 
					GtkWidget *spin, 
					GConfClient *client, 
					gchar *check_key, 
					gchar *rate_key)
{
  GtkWidget *prefbox = NULL;
  GtkWidget *compress_label = NULL;

  GConfValue *checkval = NULL;       /* value stored for the check button */
  GConfValue *rateval = NULL;        /* value stored for the spin button  */

  gint zip_rate;
  gboolean bool;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_spin");
  g_print("\ncheck: %p\nspin: %p\nclient: %p\ncheck_key: %s\nrate_key: %s", 
	  check, spin, client, check_key, rate_key);
#endif

  prefbox = rubrica_preferences_get_preferencesbox();
  compress_label = gtk_object_get_data(GTK_OBJECT(prefbox), "label_compress_rate");
  
  /* get the key related to SPIN_KEY then get the key value stored
     in gconf database 
  */
  checkval = gconf_client_get(client, check_key, NULL);

  /* if the database hasn't data for the key, then get the default value 
     from the schema
  */
  if (checkval == NULL || checkval->type != GCONF_VALUE_BOOL)
    checkval = gconf_client_get_default_from_schema(client, check_key, NULL); 
  
  if (!checkval)
    {
      error_preferences_key(check_key);

      key_error = TRUE;
      buffer_error[error] = g_strdup(check_key);
      error++; 

      bool = rubrica_preferences_get_compress();
    }
  else
    /* now I have a key value, and i can extract the boolean value */
    bool = gconf_value_get_bool(checkval); 
  
  /* check the button */
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (check), bool);

  if (bool)
    {
      /* make sensitive the spin button and the related label */
      gtk_widget_set_sensitive(spin, TRUE);
      gtk_widget_set_sensitive(compress_label, TRUE);
      
      /* extract the "compression" rate from rate_key value 
	 or read default from schema
      */
      rateval = gconf_client_get(client, rate_key, NULL);
      
      if (rateval == NULL || rateval->type != GCONF_VALUE_INT)
	rateval = gconf_client_get_default_from_schema(client, rate_key, NULL); 
      
      if (!rateval)
	{
	  error_preferences_key(rate_key);
	  
	  key_error = TRUE;
	  buffer_error[error] = g_strdup(rate_key);
	  error++; 

	  zip_rate = rubrica_preferences_get_compress_rate();
	}

      else
	/* get the compression rate and put it into spin button	 */
	zip_rate = gconf_value_get_int(rateval); 
      
      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin), zip_rate);     
    }
  else
    {
      /* user don't want a compressed addressbook, set sensitive of
	 spin button and related label to false
      */
      gtk_widget_set_sensitive(spin, FALSE);	  
      gtk_widget_set_sensitive(compress_label, FALSE);
    }
}

void rubrica_preferences_configure_entry(GtkWidget *entry, GConfClient *client, 
					 gchar *key)
{
  GConfValue *val_key;
  gchar *str;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_entry");
  g_print("\nentry: %p\nclient: %p\nkey: %s", 
	  entry, client, key);
#endif

  val_key = gconf_client_get(client, key, NULL);

  if (val_key == NULL || val_key->type != GCONF_VALUE_STRING)
    val_key = gconf_client_get_default_from_schema(client, key, NULL); 
  
  if (val_key)
    {
      str = gconf_client_get_string(client, key, NULL); 
      
      if (str)
	{
	  gtk_entry_set_text(GTK_ENTRY(entry), g_basename(str));
	  
	  g_free(str);
	}
    }
  else
    gtk_entry_set_text(GTK_ENTRY(entry), "");
}


void rubrica_preferences_configure_label(GtkWidget *label, GConfClient *client, 
					 gchar *key)
{
  GConfValue *val_key;
  gchar *str;

#ifdef DEBUG
  g_print("\nrubrica_preferences_configure_label");
  g_print("\nlabel: %p\nclient: %p\nkey: %s", 
	  label, client, key);
#endif

  val_key = gconf_client_get(client, key, NULL);

  if (val_key == NULL || val_key->type != GCONF_VALUE_STRING)
    val_key = gconf_client_get_default_from_schema(client, key, NULL); 
  
  if(val_key)
    {
      str = gconf_client_get_string(client, key, NULL); 
      
      if (str)
	{
	  gtk_label_set_text(GTK_LABEL(label), str);
	}
     else
     	gtk_label_set_text(GTK_LABEL(label), "");
    }
  else
    gtk_label_set_text(GTK_LABEL(label), "");
}


void
rubrica_preferences_revert(GtkWidget* dialog)
{
  GConfChangeSet* cs;
  GConfChangeSet* revert_cs;
  GConfClient* client;


  cs        = gtk_object_get_data(GTK_OBJECT(dialog), "changeset");
  client    = gtk_object_get_data(GTK_OBJECT(dialog), "client"); 
  /* User wants to revert to old values. So I must Get the ptr to old values
  */
  revert_cs = gtk_object_get_data(GTK_OBJECT(dialog), "revert_cs");

  if (revert_cs == NULL)
    return; /* happens on cancel, if no apply has been done */
  
  /* discard any pending changes so "apply" won't do anything  */
  gconf_change_set_clear(cs);

  /* FALSE so we don't remove committed stuff from the revert set */
  gconf_client_commit_change_set(client, revert_cs, FALSE, NULL);

  /* Set the prefs dialog contents back to the new values */
  rubrica_preferences_revert_check_button(dialog, revert_cs, 
					  RUBRICA_KEY_SHOW);
  
  rubrica_preferences_revert_checked_entry(dialog, revert_cs, 
					   RUBRICA_KEY_HAVE_BOOK,
					   RUBRICA_KEY_BOOK);
  
  rubrica_preferences_revert_checked_entry(dialog, revert_cs,
					   RUBRICA_KEY_HAVE_FOLDER,
					   RUBRICA_KEY_FOLDER);
  
  rubrica_preferences_revert_check_button(dialog, revert_cs, 
					  RUBRICA_KEY_BACKUP);
  
  rubrica_preferences_revert_spin_button(dialog, revert_cs, 
					 RUBRICA_KEY_COMPRESS,
					 RUBRICA_KEY_RATE); 
  
  rubrica_preferences_revert_check_button(dialog, revert_cs, 
					  RUBRICA_KEY_INCREASE);

  rubrica_preferences_revert_radio_buttons(dialog, revert_cs,  
					   RUBRICA_KEY_ALPHA_ORDER,
					   RUBRICA_KEY_DATE_ORDER);
  
  rubrica_preferences_revert_check_button(dialog, revert_cs, 	 
					  RUBRICA_KEY_SENSITIVE);
  
  rubrica_preferences_revert_radio_buttons(dialog, revert_cs,  
					   RUBRICA_KEY_INCOMPLETE,
					   RUBRICA_KEY_INCOMPLETE);
  
  rubrica_preferences_revert_check_button(dialog, revert_cs,
					  RUBRICA_KEY_EXIT);

  rubrica_preferences_revert_check_button(dialog, revert_cs,
					  RUBRICA_KEY_TIPS);

  rubrica_preferences_revert_radio_buttons(dialog, revert_cs,
					   RUBRICA_KEY_EXTERNAL,
					   RUBRICA_KEY_DEFAULT);
					   
  rubrica_preferences_revert_radio_buttons(dialog, revert_cs, 	
					   RUBRICA_KEY_ITALIAN,
					   RUBRICA_KEY_ENGLISH);

  rubrica_preferences_revert_entry(dialog, revert_cs, 
				   RUBRICA_KEY_USER_DICTIONARY);
  
  /* Update sensitivity of the dialog buttons */
  rubrica_preferences_update_sensitivity(dialog);
}


/*  
 */
void rubrica_preferences_revert_radio_buttons(GtkWidget *dialog, GConfChangeSet* cs, 
					      gchar* key1,gchar* key2)
{
  GConfValue* value1 = NULL;
  GConfValue* value2 = NULL;
  GConfClient* client;
  gboolean check1, check2;
  
  client = gtk_object_get_data(GTK_OBJECT(dialog), "client");

  check1 = gconf_change_set_check_value(cs, key1, &value1);
  check2 = gconf_change_set_check_value(cs, key2, &value2);

  if (check1 || check2)
    {
      GtkWidget* radio1;
      GtkWidget* radio2;
      
      radio1 = gtk_object_get_data(GTK_OBJECT(dialog), key1);
      radio2 = gtk_object_get_data(GTK_OBJECT(dialog), key2);
         
      /* If values for key1 and key2 was changed, but changes wasn't apply 
	 then no values have been stored into database for key1 and key2, 
	 so if user wants to revert, he can revert only to default value 
	 stored into schema.
       */
      if (value1 == NULL)
        {
	  /* We need to check for a default value,
             since the revert set will unset the user setting */	  
          GConfValue* def;  

          def = gconf_client_get_default_from_schema(client, key1, NULL);  
	   
          if (def)  
            {  
              if (def->type == GCONF_VALUE_BOOL)  
                {  
		  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(radio1),  
						gconf_value_get_bool(def));   
                }   
              gconf_value_free(def); 
            }	   
        }
       else
	 if (value1->type == GCONF_VALUE_BOOL)
	   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(radio1),
					 gconf_value_get_bool(value1));

      if (value2 == NULL)
	{
	 
          GConfValue* def; 

          def = gconf_client_get_default_from_schema(client, key2, NULL); 

          if (def) 
            { 
              if (def->type == GCONF_VALUE_BOOL) 
                { 
		  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(radio2),
						gconf_value_get_bool(def)); 
                } 
              gconf_value_free(def); 
            }	   
	}
      else
	if (value2->type == GCONF_VALUE_BOOL)
	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(radio2),
					gconf_value_get_bool(value2));           
    }
}


void rubrica_preferences_revert_check_button(GtkWidget *dialog, GConfChangeSet* cs, 
					     gchar* key)
{
  GConfValue* value = NULL;
  GConfClient* client;
  GtkWidget* check;
		  
  check  = gtk_object_get_data(GTK_OBJECT(dialog), key);
  client = gtk_object_get_data(GTK_OBJECT(dialog), "client");

  if (gconf_change_set_check_value(cs, key, &value))
    {    
      /* If values for key1 and key2 was changed, but changes wasn't apply 
	 then no values have been stored into database for key1 and key2, 
	 so if user wants to revert, he can revert only to default value 
	 stored into schema.
       */   
      if (value == NULL)
        {
          value = gconf_client_get_default_from_schema(client, key, NULL);  	      
	  
	  if (value && value->type == GCONF_VALUE_BOOL)	    
	    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check),
					  gconf_value_get_bool(value));
	}
    }
  else
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
				 gconf_value_get_bool(value));
}  


void rubrica_preferences_revert_checked_entry(GtkWidget *dialog, GConfChangeSet* cs, 
					      gchar* key1, gchar* key2)
{
  GConfValue* value1 = NULL;
  GConfValue* value2 = NULL;
  GConfClient* client;
  GtkWidget* check;
  GtkWidget* gnome_entry;  
  GtkWidget *entry = NULL;
		  
  check       = gtk_object_get_data(GTK_OBJECT(dialog), key1);
  gnome_entry = gtk_object_get_data(GTK_OBJECT(dialog), key2);
  client      = gtk_object_get_data(GTK_OBJECT(dialog), "client");

  if ((strcmp(key2, RUBRICA_KEY_BOOK) == 0))
    entry = gtk_object_get_data(GTK_OBJECT(dialog), "entry_addbook");  
  else
    entry = gtk_object_get_data(GTK_OBJECT(dialog), "entry_folder");
  
  if (gconf_change_set_check_value(cs, key1, &value1))
    {    
      /* If values for key1 and key2 was changed, but changes wasn't apply 
	 then no values have been stored into database for key1 and key2, 
	 so if user wants to revert, he can revert only to default value 
	 stored into schema.
      */         
      if (value1 == NULL)
	value1 = gconf_client_get_default_from_schema(client, key1, NULL);

      if (value1 && value1->type == GCONF_VALUE_BOOL)
	{	  
	  gboolean bool;
	  
	  bool = gconf_value_get_bool(value1);
	  
	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check),bool);
	  gtk_widget_set_sensitive(entry, bool);  
	}
    }
  
  if(gconf_change_set_check_value(cs, key2, &value2))
    {
      if (value2 == NULL)
	/* get default from schema */
	value2 = gconf_client_get_default_from_schema(client, key2, NULL);
      
      if (value2 && value2->type == GCONF_VALUE_STRING)
	gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_get_string(value2));      
      else
	gtk_entry_set_text(GTK_ENTRY(entry), "");
    }
}  


void rubrica_preferences_revert_spin_button(GtkWidget *dialog, GConfChangeSet* cs, 
					    gchar* key1, gchar* key2)
{
  GConfValue* checkvalue = NULL;
  GConfValue* spinvalue = NULL;  
  GConfClient* client;
  GtkWidget *check;
  GtkWidget* spin;

  check = gtk_object_get_data(GTK_OBJECT(dialog), key1);
  spin  = gtk_object_get_data(GTK_OBJECT(dialog), key2);  
  client = gtk_object_get_data(GTK_OBJECT(dialog), "client");

  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);

  if (gconf_change_set_check_value(cs, key1, &checkvalue))
    {     
      if (checkvalue == NULL)
	checkvalue = gconf_client_get_default_from_schema(client, key1, NULL);
      
      if (checkvalue && checkvalue->type == GCONF_VALUE_BOOL)
	{
	  gboolean bool;
	  
	  bool = gconf_value_get_bool(checkvalue);
	  
	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check), bool);      
	  gtk_widget_set_sensitive(spin, bool);
	}
    }
      
  if (gconf_change_set_check_value(cs, key2, &spinvalue))
        {
	  gint rate;
	  
	  if (spinvalue == NULL)
	    spinvalue = gconf_client_get_default_from_schema(client, key2, NULL);

	  if (spinvalue && spinvalue->type == GCONF_VALUE_INT)
	    {
	      rate = gconf_value_get_int(spinvalue);
	      
	      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin), rate);	  	  
	      xmlSetCompressMode(rate);
	    }	  
	  else
	    {
	      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin), 0); 	  
	      xmlSetCompressMode(0);      
	    }	  
	}
}


void rubrica_preferences_revert_entry(GtkWidget *dialog, GConfChangeSet* cs, 
				      gchar* key)
{
  GConfValue* value = NULL;
  GConfClient* client;
  
  client = gtk_object_get_data(GTK_OBJECT(dialog), "client");
  
  if (gconf_change_set_check_value(cs, key, &value))
    {
      GtkWidget* entry;
    
      entry = gtk_object_get_data(GTK_OBJECT(dialog), key);     
     
      if (value == NULL)
	value = gconf_client_get_default_from_schema(client, key, NULL);
      
      if (value && value->type == GCONF_VALUE_STRING)
	{
	  gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_get_string(value));
	  gconf_value_free(value);      
	}
      else
	gtk_entry_set_text(GTK_ENTRY(entry), "");      
    }
}


/****************** 
 *                *
 *  GET ROUTINES  *
 *                *
 ******************/

/*  return true is this is the first time that 
    rubrica is running after gconf "era"    
 */
gboolean rubrica_preferences_get_first_run(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_FIRST_RUN, NULL);

  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_FIRST_RUN, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_FIRST_RUN, NULL);   
  
  return TRUE;
}

/*  return the last time rubrica was run
*/
gint rubrica_preferences_get_last_run(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_LAST_RUN, NULL);

  if (value == NULL || value->type != GCONF_VALUE_INT)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_LAST_RUN, NULL); 

  if (value)
    return gconf_client_get_int(client, RUBRICA_KEY_LAST_RUN, NULL);   
  
  return time(NULL);
}

/*  return last opened addressbook
*/
gchar *rubrica_preferences_get_last_book(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_LAST_BOOK, NULL);

  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_LAST_BOOK, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_LAST_BOOK, NULL);    
  
  return NULL;
}

/*  return user home directory
*/
gchar *rubrica_preferences_get_home(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HOME, NULL);

  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HOME, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_HOME, NULL);    
  /* else */
  return NULL; 
}


gboolean rubrica_preferences_get_show_path(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW, NULL);

  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW, NULL);   

  return TRUE;
}

/*
  return true if user wants that rubrica load an addressbook at start
  false otherwise
*/
gboolean rubrica_preferences_get_have_default_addressbook(void)
{
  GConfClient *client;
  GConfValue  *value;

  client  = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HAVE_BOOK, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HAVE_BOOK, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_HAVE_BOOK, NULL);  

  return FALSE;
}

/* 
   is user wants start with an addressbook, this funcion returns  
   addressbook's path and file
*/
gchar *rubrica_preferences_get_book(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_BOOK, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_BOOK, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_BOOK, NULL);   
  else
    rubrica_preferences_display_messages("rubrica_preferences_get_book");

  return NULL;
}

/*
  return true if users wants to save all 
  addressbook in a default folder
*/
gboolean rubrica_preferences_get_have_default_folder(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HAVE_FOLDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HAVE_FOLDER, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_HAVE_FOLDER, NULL);    

  return FALSE;
}

/* 
   if user wants to save addressbook in a 
   default folder, this function return the folder
*/
gchar* rubrica_preferences_get_default_folder(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_FOLDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_FOLDER, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_FOLDER, NULL);  

  return NULL;
}

/*
  return true is user want to do backup
*/
gboolean rubrica_preferences_get_do_backup(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_BACKUP, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_BACKUP, NULL); 
  
  if (value) 
    return gconf_client_get_bool(client, RUBRICA_KEY_BACKUP, NULL);  

  return FALSE;
}

/*
  return true if user want to compress his addressbooks
*/
gboolean rubrica_preferences_get_compress(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_COMPRESS, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_COMPRESS, NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_COMPRESS, NULL);  

  return FALSE;
}

/* 
   if user wants compressed addressbooks. this funcion return 
   the compression rate
*/
gint rubrica_preferences_get_compress_rate(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_RATE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_INT)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_RATE, NULL); 

  if (value)  
    return gconf_client_get_int(client, RUBRICA_KEY_RATE, NULL);  
  
  return 0;
}

/* 
   return true if cards's order is increasing
   return false if cards's order is decreasing
*/
gboolean rubrica_preferences_get_increasing_order(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_INCREASE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_INCREASE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_INCREASE, NULL);

  return TRUE;
}

/*
  return true if cards order is alphabetic
*/
gboolean rubrica_preferences_get_alphabetic_order(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_ALPHA_ORDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_ALPHA_ORDER, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_ALPHA_ORDER, NULL);

  return TRUE;
}

/*
  return true if cards order is by date
*/
gboolean rubrica_preferences_get_date_order(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_DATE_ORDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_DATE_ORDER, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_DATE_ORDER, NULL);

  return FALSE;
}

/*
  return true if search is case sensitive
*/
gboolean rubrica_preferences_get_case_sensitive_search(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SENSITIVE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SENSITIVE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_SENSITIVE, NULL);

  return TRUE;
}

/*
  return true if search is on complete string
*/
gboolean rubrica_preferences_get_complete_search(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_COMPLETE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_COMPLETE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_COMPLETE, NULL);

  return TRUE;
}

/*
  return true if search is on incomplete string
*/
gboolean rubrica_preferences_get_incomplete_search(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_INCOMPLETE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_INCOMPLETE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_INCOMPLETE, NULL);

  return FALSE;
}

/*
  return true if user want to exit without confirm
*/
gboolean rubrica_preferences_get_exit(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_EXIT, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_EXIT, NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_EXIT, NULL);

  return TRUE;
}


/*
  return true is user want tips at start 
*/
gboolean rubrica_preferences_get_tips(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_TIPS, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_TIPS, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_TIPS, NULL);

  return FALSE;
}

/*
  return true if user want to use one of  
  the default dictionary 
*/
gboolean rubrica_preferences_get_use_default_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_DEFAULT, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_DEFAULT, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_DEFAULT, NULL);

  return TRUE;
}

/*
  return true if user want to use an external 
  dictionary (personal dictionary)
*/
gboolean rubrica_preferences_get_use_user_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_EXTERNAL, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_EXTERNAL, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_EXTERNAL, NULL);

  return FALSE;
}

/*
  return true if user want to use italian dictionary 
*/
gboolean rubrica_preferences_get_use_italian_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_ITALIAN, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_ITALIAN, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_ITALIAN, NULL);

  return TRUE;
}


/*
  return true if user want to use english dictionary 
*/
gboolean rubrica_preferences_get_use_english_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_ENGLISH, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_ENGLISH, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_ENGLISH, NULL);

  return FALSE;
}


/*
  return true if user has his dictionary
*/
gboolean rubrica_preferences_get_user_has_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HAS_DICTIONARY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HAS_DICTIONARY, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_HAS_DICTIONARY, NULL);  

  return FALSE;
}

gchar *rubrica_preferences_get_dictionary_home(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_DICTIONARY_HOME, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_DICTIONARY_HOME, 
						 NULL); 

  if (value)   
    return gconf_client_get_string(client, RUBRICA_KEY_DICTIONARY_HOME, NULL);    

  return NULL;
}


/*
  if user has dictionary, return dictionary filename
*/
gchar* rubrica_preferences_get_user_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;
  
  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_USER_DICTIONARY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_USER_DICTIONARY, NULL); 
  
  if (value)   
    return gconf_client_get_string(client, RUBRICA_KEY_USER_DICTIONARY, NULL);    

  return NULL;
}

gchar *rubrica_preferences_get_string_key(gchar *key)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, key, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, key, NULL); 

  if (value)   
    return gconf_client_get_string(client, key, NULL);  

  return NULL;
}


/*
  return user dictionary language
  (language is equal to dictionary filename)
  Klingon language has Klingon.dict dictionary
*/
gchar* rubrica_preferences_get_language(void)
{
  GConfClient *client;
  GConfValue  *value;
  gchar *buffer = NULL, *str = NULL;
  
  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_USER_DICTIONARY, NULL);

  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_USER_DICTIONARY, NULL); 

  if (value)
    {
      buffer = gconf_client_get_string(client, RUBRICA_KEY_USER_DICTIONARY, NULL);
  
      if (buffer)
	{
	  str = g_basename(buffer);
	  g_strreverse(str);
	  strtok(str, ".");
	  g_strreverse(str);
	}
      else
	str = NULL;
    }
  
  return (gchar*) str;
}


/******************
 *                *
 *  SET ROUTINES  *
 *                *
 ******************/
void rubrica_preferences_set_first_run(gboolean bool)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_bool(client, RUBRICA_KEY_FIRST_RUN, bool, NULL);  
}
  
void rubrica_preferences_set_last_run(time_t last_run)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_int(client, RUBRICA_KEY_LAST_RUN, last_run, NULL);  
}

void rubrica_preferences_set_last_book(gchar *filename)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_LAST_BOOK, filename, NULL);   
}

void rubrica_preferences_set_home(gchar *home)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_HOME, home, NULL);   
}

void rubrica_preferences_set_have_default_book(gboolean bool)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_bool(client, RUBRICA_KEY_HAVE_BOOK, bool, NULL);  
}

void rubrica_preferences_set_have_default_folder(gboolean bool)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_bool(client, RUBRICA_KEY_HAVE_FOLDER, bool, NULL);  
}

void rubrica_preferences_set_book(gchar *str)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_BOOK, str, NULL);  
}

void rubrica_preferences_set_folder(gchar *str)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_FOLDER, str, NULL);  
}


void rubrica_preferences_set_compress_rate(gint rate)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_int(client, RUBRICA_KEY_RATE, rate, NULL);  
}

void rubrica_preferences_set_increasing_order(gboolean state)
{
  GConfClient* client;
  
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_INCREASE, state, NULL);
}


void rubrica_preferences_set_alphabetic_order(gboolean state)
{
  GConfClient* client;
  
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_ALPHA_ORDER, state, NULL);
}


void rubrica_preferences_set_date_order(gboolean state)
{
  GConfClient* client;
  
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_DATE_ORDER, state, NULL);
}


void rubrica_preferences_set_case_sensitive_search(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_SENSITIVE, state, NULL);  
}

void rubrica_preferences_set_complete_search(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_COMPLETE, state, NULL);  
}

void rubrica_preferences_set_incomplete_search(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_INCOMPLETE, state, NULL);
}

void rubrica_preferences_set_tips(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_TIPS, state, NULL);
}

void rubrica_preferences_set_user_dictionary(gchar *dict)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, RUBRICA_KEY_USER_DICTIONARY, dict, NULL);   
}

void rubrica_preferences_set_dictionary_home(gchar *homedict)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, RUBRICA_KEY_DICTIONARY_HOME, homedict, NULL);   
}


void rubrica_preferences_set_string_key(gchar *key, gchar *val)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, key, val, NULL);   
}

void rubrica_preferences_set_null_key(gchar *key)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, key, NULL, NULL);   
}

/* ********************** */

void rubrica_preferences_set_user_dictionary_loaded(gboolean state)
{
  user_dictionary_loaded = state;
}

gboolean rubrica_preferences_get_user_dictionary_loaded()
{
  return user_dictionary_loaded;
}

