/*
*  program name: Rubrica <http://digilander.iol.it/nfragale/download.html>
*  file: prefer_cb.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf-client.h>
#include <gnome-xml/tree.h>

#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer.h"
#include "dictionary.h"


void
rubrica_preferences_ok_clicked (GtkButton *button, gpointer  user_data)
{
  GtkWidget* dialog = user_data;
  
  rubrica_preferences_apply(dialog);
  gtk_widget_hide(dialog); 
}


void
rubrica_preferences_apply_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox = user_data;

  rubrica_preferences_apply(prefbox);
}


void
rubrica_preferences_revert_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox = user_data;

  rubrica_preferences_revert(prefbox);
}


void 
rubrica_preferences_close_dialog  (GtkButton  *button, gpointer user_data)
{
  GtkWidget *w = user_data;

  gtk_widget_hide(w);
}



/*    widget callbacks
*/
void on_check_button_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;

  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(key != NULL);

  /*    get ptr to the preferences window dialog and to the GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  /* get the new button state */
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  /* store the new value */
  gconf_change_set_set_bool(cs, key, state);

  /* update preferences buttons sensitivity */
  rubrica_preferences_update_sensitivity(prefbox);
}


void
on_check_files_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GtkWidget *gentry;
  GtkWidget *entry;
  
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  gchar *key2;

  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_HAVE_BOOK) == 0))
    {
      /* get addressbook ptrs */
      gentry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_BOOK);
      entry  = gtk_object_get_data(GTK_OBJECT(prefbox), "entry_addbook");
      key2   = g_strdup(RUBRICA_KEY_BOOK);
    }
  else
    {
      /* get folder ptrs */
      gentry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_FOLDER);
      entry  = gtk_object_get_data(GTK_OBJECT(prefbox), "entry_folder");      
      key2   = g_strdup(RUBRICA_KEY_FOLDER);
    }
  
  if(!state)
    {      
      gtk_entry_set_text(GTK_ENTRY(entry), "");
      gconf_change_set_unset(cs, key2);      
    }
  
  gtk_widget_set_sensitive(gentry, state);
 
  gconf_change_set_set_bool(cs, key, state);
  
  g_free(key2); 
}

void on_entry_files_changed (GtkEditable *editable, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gchar *text;
  gchar *key = user_data;
  
  g_return_if_fail(editable != NULL);
  g_return_if_fail(user_data != NULL);  

  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  
  if (*text != '\0')
    gconf_change_set_set_string(cs, key, text);
  else
    gconf_change_set_unset(cs, key);
  
  g_free(text);
  
  rubrica_preferences_update_sensitivity(prefbox);
}

void on_check_compress_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox, *label, *spin; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;

  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  prefbox = rubrica_preferences_get_preferencesbox();

  cs    = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  label = gtk_object_get_data(GTK_OBJECT(prefbox), "label_compress_rate");
  spin  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_RATE);

  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  gtk_widget_set_sensitive(label, state);
  gtk_widget_set_sensitive(spin, state);
  
  gconf_change_set_set_bool(cs, key, state);

  if (!state)          /* if rubrica isn't compress,store 0 */
    gconf_change_set_set_int(cs, RUBRICA_KEY_RATE, 0);
    
  rubrica_preferences_update_sensitivity(prefbox);
}

void on_spin_rate_activate (GtkWidget *spin, gpointer user_data)
{ 
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gint val;
  gchar *key = user_data;

  g_return_if_fail(spin != NULL);
  g_return_if_fail(user_data != NULL);

  prefbox = rubrica_preferences_get_preferencesbox();

  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  val = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin));
  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);

  /* store new compression rate in the key
     and set xml compression mode 
  */
  gconf_change_set_set_int(cs, key, val);
  xmlSetCompressMode(val);

  rubrica_preferences_update_sensitivity(prefbox);
}

void on_radio_order_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;

  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  /*    get ptr to preferences window dialog anto to GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_ALPHA_ORDER) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ALPHA_ORDER, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DATE_ORDER, !state);
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ALPHA_ORDER, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DATE_ORDER, state);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}


void
on_radio_search_type_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  /*    get ptr to preferences window dialog anto to GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_COMPLETE) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_COMPLETE, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_INCOMPLETE, !state);
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_COMPLETE, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_INCOMPLETE, state);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}

void on_option_search_clicked(GtkToggleButton *togglebutton, gpointer user_data)
{
}

/*
  witch dictionary will be used

  default (italian or english)

  external (user dictionary)
*/
void
on_radio_witch_dict_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GtkWidget *radio_italian;
  GtkWidget *radio_english;
  GtkWidget *entry;
  GtkWidget *label_default;
  GtkWidget *label_language;
  GtkWidget *notebook;
  GtkWidget *label_io;
  GtkWidget *label_dict;
  GtkWidget *load;
  GtkWidget *save;
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  /*    get ptr to preferences window dialog anto to GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();

  load  = gtk_object_get_data(GTK_OBJECT(prefbox), "load");
  save  = gtk_object_get_data(GTK_OBJECT(prefbox), "save"); 
  entry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_USER_DICTIONARY);
  notebook   = gtk_object_get_data(GTK_OBJECT(prefbox), "notebook_dict");
  label_io   = gtk_object_get_data(GTK_OBJECT(prefbox), "label_io");
  label_dict = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
  label_language = gtk_object_get_data(GTK_OBJECT(prefbox), "label_language");
  radio_italian  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ITALIAN);
  radio_english  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ENGLISH);
  label_default  = gtk_object_get_data(GTK_OBJECT(prefbox), "label_default_dict");
  
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_DEFAULT) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DEFAULT, state);
      gconf_change_set_set_bool(cs, RUBRICA_KEY_EXTERNAL, !state);  

      gtk_widget_set_sensitive(radio_italian, state);
      gtk_widget_set_sensitive(radio_english, state);
      gtk_widget_set_sensitive(label_default, state);

      gtk_widget_set_sensitive(entry, !state);
      gtk_widget_set_sensitive(label_language, !state);
      gtk_widget_set_sensitive(notebook, !state);
      gtk_widget_set_sensitive(label_io, !state);
      gtk_widget_set_sensitive(label_dict, !state);
      gtk_widget_set_sensitive(load, !state); 
      gtk_widget_set_sensitive(save, !state); 
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DEFAULT, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_EXTERNAL, state);      

      gtk_widget_set_sensitive(radio_italian, !state);
      gtk_widget_set_sensitive(radio_english, !state);
      gtk_widget_set_sensitive(label_default, !state);

      gtk_widget_set_sensitive(entry, state);
      gtk_widget_set_sensitive(label_language, state);
      gtk_widget_set_sensitive(notebook, state);
      gtk_widget_set_sensitive(label_io, state);
      gtk_widget_set_sensitive(label_dict, state);
      gtk_widget_set_sensitive(load, state); 
      gtk_widget_set_sensitive(save, state); 
    }

  rubrica_preferences_update_sensitivity(prefbox);
}

/*
  default dictionary that will be used
  
  italian (default)
  english
*/
void
on_radio_dictionary_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  /*    get ptr to preferences window dialog anto to GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_ITALIAN) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ITALIAN, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ENGLISH, !state);
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ITALIAN, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ENGLISH, state);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}


/*  callback richiamata ad ogni variazione
    dell'entry relativa al nome/linguaggio 
    del dizionario
*/
void on_entry_user_lang_changed(GtkEditable *editable, gpointer user_data)
{  
  GtkWidget *prefbox; 
  GtkWidget *label;
  GConfChangeSet *cs;
  gchar *text;
  gchar *key = user_data;  

  /*    get ptr to configuration dialog    */
  prefbox = rubrica_preferences_get_preferencesbox();

  /*    get ptr to GConf ChangeSet  */
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  /*     get the ptr to the label that show the dictionary file name, 
	 clear it, 
	 get the text typed into entry 
  */
  label = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
  gtk_label_set_pattern(GTK_LABEL(label), NULL);
  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);

  /*    if text was entered show it into label, and set into changeset
   */
  if (strlen(text) > 0)
    {
      gtk_label_set_text(GTK_LABEL(label), text);
      rubrica_preferences_set_user_dictionary(text);
      
      gconf_change_set_set_string(cs, key, text);
    }
  else
    {
      gtk_label_set_text(GTK_LABEL(label), "");
      
      gconf_change_set_unset(cs, key);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}

/*  Callback richiamata ad ogni cambiamento
    delle entry relative al dizionario 
    contenuto nel notebook

    notebook entries's callbacks
*/
void 
on_dictionary_entry_changed(GtkEditable *editable, gpointer user_data)
{
  GtkWidget *prefbox;
  GConfClient *client;
  gchar *text;
  gchar *key = user_data;

  /* get ptr to dialog box */
  prefbox = rubrica_preferences_get_preferencesbox();

  /*    get ptr to GConf client  */
  client = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  /*    get the text typed into entry 
  */
  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  
  gconf_client_set_string(client, key, text, NULL);
}

/*  Notebook buttons's callbacks
*/
void
on_load_dictionary_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox;
  GConfClient *client;
  gboolean err;
 
  prefbox    = rubrica_preferences_get_preferencesbox();
  client     = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  err = rubrica_dictionary_load_user_dictionary(client);
  
  if (!err)
    rubrica_dictionary_display_dictionary(prefbox, client);
}

void
on_save_dictionary_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox;
  GConfClient *client;
  gchar *dictionary;
 
  prefbox = rubrica_preferences_get_preferencesbox();
  client = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  if (rubrica_preferences_get_use_user_dictionary())
    {
      dictionary = rubrica_preferences_get_user_dictionary();
      
      if (!dictionary)
	{
	  /* errore ancora non esiste dizionario */
	}
      else
	rubrica_dictionary_save_user_dictionary(client, dictionary);

      g_free(dictionary);
    }
}

void
on_show_rules_clicked  (GtkButton  *button, gpointer user_data)
{
  GtkWidget *w;

  w = create_translationbox();
  gtk_widget_show(w);
}










