/*
*  Rubrica
*  file: rubrica.h
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_H
#define _RUBRICA_H

#include <gnome.h>
#include <gconf/gconf-client.h>

#include "view.h"

typedef struct _Rubrica          Rubrica;
typedef struct _RubricaItem      RubricaItem;
typedef struct _RubricaPersonal  RubricaPersonal;
typedef struct _RubricaNet       RubricaNet;
typedef struct _RubricaTelephone RubricaTelephone;
typedef struct _RubricaAddress   RubricaAddress;
typedef struct _RubricaCompany   RubricaCompany;
typedef struct _RubricaWork      RubricaWork;
typedef struct _RubricaNotes     RubricaNotes;
typedef struct _TelNum           TelNum;

typedef enum  {
  TELEPHONE_HOME = 0,
  TELEPHONE_WORK,
  TELEPHONE_FAX,
  TELEPHONE_CELLPHONE,
  TELEPHONE_OTHER,
  TELEPHONE_UNKNOWN
} TELEPHONE_TYPE;


struct _Rubrica
{
  GList *rub;             /* the addressbook list */

  gboolean new;           /* true  if this is new addressbook (just done) 
			     false if it has one or more item          */
  gboolean empty;         /* true if rub list is empty, false if otherwhise */
  gboolean modified;      /* true if rubrica is modified, false if not */
  
  gchar *name;            /* addressbook's name */
  gchar *path;            /* addressbook's path */

  GtkWidget *child;       /* notebook's child, contains the clist ptr */
  GtkWidget *clist;       /* ptr to the clist where addressbook is shown */
  GtkWidget *label;       /* label for addressbook name */

  gint items;             /* # of item in current addressbook */
  gint riga;              /* row of selected item*/
  gint colonna;           /* column of selected item */

  gint pagina;            /* current notebook's page */  
};


struct _RubricaPersonal
{
  gchar *first_name;
  gchar *middle_name;
  gchar *last_name;

  gchar *profession;
  gchar *name_prefix;
  gchar *title;

  gboolean birthday_setted;
  time_t birthday;
};

struct _RubricaAddress
{
  gchar *street;
  gchar *number;
  gchar *zip_code;
  gchar *city;
  gchar *province;
  gchar *state;
  gchar *country;
};

struct _RubricaNet
{
  GList *web_list;
  GList *mail_list;

  gint nweb;
  gint nmail;  
};


struct _RubricaTelephone
{
  GList *tel_list;

  gint ntel;
};


struct _RubricaCompany
{
  gchar *name;
  gchar *street;
  gchar *number;
  gchar *zip_code;
  gchar *city;
  gchar *province;
  gchar *country;
  gchar *web;
  gchar *email;
  gchar *operator;
  gchar *fax;
  gchar *green;
  gchar *customer_care;
  gchar *notes;
};

struct _RubricaWork
{
  gchar *assigment;
  gchar *organization;
  gchar *department;
  gchar *sub_dep;
  gchar *secretary_name;
  gchar *secretary_phone;
};

struct _RubricaNotes
{
  gboolean married;
  gboolean children;

  time_t birthday;
  time_t anniversary;

  gchar *spouse_name;
  
  gchar *child;
  gchar *hobby;
  gchar *notes;

  gchar *public_key;
};

struct _TelNum {
  gchar *numero_telefono;
  gchar *tipo;
};


struct _RubricaItem {
  gboolean editabile;
  gboolean cancellabile;
  gint group;

  gchar *scheda;

  RubricaPersonal  personal;
  RubricaAddress   address;
  RubricaNet       net;
  RubricaTelephone telephone;
  RubricaCompany   company;
  RubricaWork      work;
  RubricaNotes     notes;

  time_t created;
  time_t last_change;
};


/*    Prototipi
 */


/* ***********************************************
    prelievo e impostazione della lista a rubrica
*/
Rubrica *rubrica_rubrica_new(void);

void rubrica_init(GConfClient *client, gboolean first_run);
void rubrica_init_gconf(GConfClient *client);

void rubrica_update_time(void);
gboolean rubrica_start_with_user_addressbook();
gchar *rubrica_get_filename();

void rubrica_copy_rubrica(Rubrica *rub);
void rubrica_save_rubrica(void);
void rubrica_restore_rubrica(void);

void rubrica_set_current_page(gint n);
gint rubrica_get_current_page(void);

/* ----  metodi operanti sulla struttura Rubrica  ---- */

/**
 **
 **  get
 **
 **
 **/
GList *rubrica_get_rubrica(void);

inline gboolean rubrica_is_new(void);
inline gboolean rubrica_is_empty(void);
inline gboolean rubrica_is_modified(void);

inline gchar *rubrica_get_path(void);
inline gchar *rubrica_get_name(void);

inline GtkWidget *rubrica_get_child(void);
inline GtkWidget *rubrica_get_clist(void);
inline GtkWidget *rubrica_get_label(void);

inline gint rubrica_get_items(void);
inline gint rubrica_get_row(void);
inline gint rubrica_get_column(void);

inline gint rubrica_get_page(void);

/**
 **
 **  set
 **
 **
 **/
void rubrica_set_rubrica(gpointer ptr);

inline void rubrica_set_new(gboolean state);
inline void rubrica_set_empty(gboolean state);
inline void rubrica_set_modified(gboolean state);

void rubrica_set_path(gchar *str);
void rubrica_set_name(gchar *str);
void rubrica_set_label_text(gchar *str);

/*   non si pu operare su child e clist
*/
void rubrica_set_page(gint n);
void rubrica_set_row(gint n);
void rubrica_set_column(gint n);

/* ----  *********************************************  ---- */



/* ************************************************** 
  metodi per:
  - l'inserimento, 
  - cancellazione  
  - modifica 
  di un elemento di rubrica nella lista rubrica       
*/
void rubrica_inserisci_scheda(RubricaItem *r);
void rubrica_modifica_scheda(RubricaItem *r);
void rubrica_elimina_scheda(gint n);


void rubrica_svuota_memoria(GList *rubrica);
void rubrica_free_data(gpointer data, gpointer user_data);
void rubrica_free(gchar *str);


RubricaItem *rubrica_prendi_elemento(gint n);
void rubrica_inserisci_elemento(RubricaItem *r);
gint rubrica_modifica_elemento(RubricaItem *r);
gboolean rubrica_elimina_elemento(GList *rubrica, gint n);


/* *************************************************** 
   funzioni per la navigazione  tra le schede inserite
*/
void rubrica_mostra_prima_scheda();
void rubrica_mostra_ultima_scheda();

void rubrica_scheda_precedente();
void rubrica_scheda_successiva();
void rubrica_scheda_ennesima(gint n);

void rubrica_mostra_scheda(RubricaItem *i);
void rubrica_visualizza_dati(GtkCList *clist, gchar *item[18][4]);
void rubrica_visualizza_dati_rimanenti(GtkCList *clist, gchar *item[53][4], gint pos);
/* ****************************************** */

/*
  funzioni per:
  taglia, copia, incolla (cut, copy, paste)
*/
void rubrica_item_cut(void);
void rubrica_item_copy(void);
void rubrica_item_paste(void);

/* ****************************************** */
inline gboolean rubrica_other_are_modified();

void rubrica_set_range(gint n);
gint rubrica_get_range(void);
gchar *rubrica_convert_time(time_t t, gboolean has_hour);

void rubrica_set_row_selected(gboolean bool);
gboolean rubrica_is_row_selected(void);


#endif










